Re: [PATCH] sound/pci/hda: Changes 'blacklist/whitelist' to 'blocklist/allowlist'

2020-07-15 Thread Paul Schulz
Good news is that appears to be the only case of this particular usage
with MODULE_PARM_DESC
Searching for 'blacklist' and MODULE_PARM gives the following:

sound/pci/hda/hda_intel.c:183:MODULE_PARM_DESC(pm_blacklist, "Enable
power-management blacklist");
arch/x86/crypto/camellia_glue.c:1473:MODULE_PARM_DESC(force, "Force
module load, ignore CPU blacklist");
arch/x86/crypto/twofish_glue_3way.c:251:MODULE_PARM_DESC(force, "Force
module load, ignore CPU blacklist");
arch/x86/crypto/des3_ede_glue.c:467:MODULE_PARM_DESC(force, "Force
module load, ignore CPU blacklist");
arch/x86/crypto/blowfish_glue.c:423:MODULE_PARM_DESC(force, "Force
module load, ignore CPU blacklist");

On Thu, 16 Jul 2020 at 03:45, Paul Schulz  wrote:
>
> Yep. +1 for logic
>
> On Thu, 16 Jul 2020 at 03:11, Jonathan Corbet  wrote:
> >
> > On Thu, 16 Jul 2020 01:52:04 +0930
> > Paul Schulz  wrote:
> >
> > > -static bool pm_blacklist = true;
> > > -module_param(pm_blacklist, bool, 0644);
> > > -MODULE_PARM_DESC(pm_blacklist, "Enable power-management blacklist");
> > > +static bool pm_blocklist = true;
> > > +module_param(pm_blocklist, bool, 0644);
> > > +MODULE_PARM_DESC(pm_blocklist, "Enable power-management blocklist");
> >
> > This will break any user specifying this parameter now, which isn't
> > something you want to do, methinks...
> >
> > jon


Re: [PATCH] sound/pci/hda: Changes 'blacklist/whitelist' to 'blocklist/allowlist'

2020-07-15 Thread Paul Schulz
Yep. +1 for logic

On Thu, 16 Jul 2020 at 03:11, Jonathan Corbet  wrote:
>
> On Thu, 16 Jul 2020 01:52:04 +0930
> Paul Schulz  wrote:
>
> > -static bool pm_blacklist = true;
> > -module_param(pm_blacklist, bool, 0644);
> > -MODULE_PARM_DESC(pm_blacklist, "Enable power-management blacklist");
> > +static bool pm_blocklist = true;
> > +module_param(pm_blocklist, bool, 0644);
> > +MODULE_PARM_DESC(pm_blocklist, "Enable power-management blocklist");
>
> This will break any user specifying this parameter now, which isn't
> something you want to do, methinks...
>
> jon


[PATCH] sound/pci/hda: Changes 'blacklist/whitelist' to 'blocklist/allowlist'

2020-07-15 Thread Paul Schulz
This edit changes instances of 'blacklist' and 'whitelist' to
'blocklist' and 'allowlist' (and associated variations)
in sound/pci/hda.

This is a functionally trivial patch and has no other effect.

Signed-off-by: Paul Schulz 
---
 Documentation/sound/hd-audio/notes.rst |  2 +-
 sound/pci/hda/hda_intel.c  | 32 +-
 sound/pci/hda/patch_realtek.c  |  6 ++---
 3 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/Documentation/sound/hd-audio/notes.rst 
b/Documentation/sound/hd-audio/notes.rst
index 0f3109d9abc8..1024ca1a7bd2 100644
--- a/Documentation/sound/hd-audio/notes.rst
+++ b/Documentation/sound/hd-audio/notes.rst
@@ -142,7 +142,7 @@ thus we disabled MSI for them.
 There seem also still other devices that don't work with MSI.  If you
 see a regression wrt the sound quality (stuttering, etc) or a lock-up
 in the recent kernel, try to pass ``enable_msi=0`` option to disable
-MSI.  If it works, you can add the known bad device to the blacklist
+MSI.  If it works, you can add the known bad device to the blocklist
 defined in hda_intel.c.  In such a case, please report and give the
 patch back to the upstream developer. 
 
--- net/Makefile.oldThu Nov  9 23:06:00 2000
+++ net/MakefileThu Nov  9 22:18:40 2000
@@ -7,7 +7,7 @@
 
 O_TARGET :=network.o
 
-mod-subdirs := ipv4/netfilter ipv6/netfilter ipx irda atm netlink
+mod-subdirs := ipv4/netfilter ipv6/netfilter ipx irda atm netlink sched
 export-objs := netsyms.o
 
 subdir-y :=core ethernet

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
Please read the FAQ at http://www.tux.org/lkml/



[Patch] QoS as modules in 2.4.0-test10 not compiling.

2000-11-09 Thread Paul Schulz

Greetings,

I've been trying to compile the kernel with the QoS code as modules.

The net/Makefile didn't have 'sched' listed as a module subdirectory,
so it wasntt getting walked in a make_modules... any way, the
following patch fixes the problem.

Paul Schulz ([EMAIL PROTECTED])
Foursticks Systems

--- net/Makefile.oldThu Nov  9 23:06:00 2000
+++ net/MakefileThu Nov  9 22:18:40 2000
@@ -7,7 +7,7 @@
 
 O_TARGET :=network.o
 
-mod-subdirs := ipv4/netfilter ipv6/netfilter ipx irda atm netlink
+mod-subdirs := ipv4/netfilter ipv6/netfilter ipx irda atm netlink sched
 export-objs := netsyms.o
 
 subdir-y :=core ethernet

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
Please read the FAQ at http://www.tux.org/lkml/



Re: Problems with Tulip driver in 2.2 and 2.4

2000-10-15 Thread Paul Schulz


I'm seeing a similar problem with the Xircom Realport card
which uses the 'xircom_tulip_cb' driver.

Workaround: 

Putting the card into promiscuous mode seems to get it going again.
If feels like (but I haven't investigated further) the ARP table isn't
being updated properly.

This was discovered by finding that running 'tcpdump' on the interface
make it work again. 

diff --git a/sound/pci/hda/hda_intel.c b/sound/pci/hda/hda_intel.c
index 3565e2ab0965..c7596773358b 100644
--- a/sound/pci/hda/hda_intel.c
+++ b/sound/pci/hda/hda_intel.c
@@ -178,9 +178,9 @@ module_param(power_save, xint, 0644);
 MODULE_PARM_DESC(power_save, "Automatic power-saving timeout "
 "(in second, 0 = disable).");
 
-static bool pm_blacklist = true;
-module_param(pm_blacklist, bool, 0644);
-MODULE_PARM_DESC(pm_blacklist, "Enable power-management blacklist");
+static bool pm_blocklist = true;
+module_param(pm_blocklist, bool, 0644);
+MODULE_PARM_DESC(pm_blocklist, "Enable power-management blocklist");
 
 /* reset the HD-audio controller in power save mode.
  * this may give more power-saving, but will take longer time to
@@ -1508,7 +1508,7 @@ static bool check_hdmi_disabled(struct pci_dev *pci)
 #endif /* SUPPORT_VGA_SWITCHEROO */
 
 /*
- * white/black-listing for position_fix
+ * allow/block-listing for position_fix
  */
 static const struct snd_pci_quirk position_fix_list[] = {
SND_PCI_QUIRK(0x1028, 0x01cc, "Dell D820", POS_FIX_LPIB),
@@ -1601,7 +1601,7 @@ static void assign_position_fix(struct azx *chip, int fix)
 }
 
 /*
- * black-lists for probe_mask
+ * block-lists for probe_mask
  */
 static const struct snd_pci_quirk probe_mask_list[] = {
/* Thinkpad often breaks the controller communication when accessing
@@ -1649,9 +1649,9 @@ static void check_probe_mask(struct azx *chip, int dev)
 }
 
 /*
- * white/black-list for enable_msi
+ * allow/block-list for enable_msi
  */
-static const struct snd_pci_quirk msi_black_list[] = {
+static const struct snd_pci_quirk msi_block_list[] = {
SND_PCI_QUIRK(0x103c, 0x2191, "HP", 0), /* AMD Hudson */
SND_PCI_QUIRK(0x103c, 0x2192, "HP", 0), /* AMD Hudson */
SND_PCI_QUIRK(0x103c, 0x21f7, "HP", 0), /* AMD Hudson */
@@ -1674,7 +1674,7 @@ static void check_msi(struct azx *chip)
return;
}
chip->msi = 1;  /* enable MSI as default */
-   q = snd_pci_quirk_lookup(chip->pci, msi_black_list);
+   q = snd_pci_quirk_lookup(chip->pci, msi_block_list);
if (q) {
dev_info(chip->card->dev,
 "msi for device %04x:%04x set to %d\n",
@@ -2074,11 +2074,11 @@ static void pcm_mmap_prepare(struct snd_pcm_substream 
*substream,
 #endif
 }
 
 /* Blacklist for skipping the whole probe:
  * some HD-audio PCI entries are exposed without any codecs, and such devices
  * should be ignored from the beginning.
  */
-static const struct pci_device_id driver_blacklist[] = {
+static const struct pci_device_id driver_blocklist[] = {
{ PCI_DEVICE_SUB(0x1022, 0x1487, 0x1043, 0x874f) }, /* ASUS ROG Zenith 
II / Strix */
{ PCI_DEVICE_SUB(0x1022, 0x1487, 0x1462, 0xcb59) }, /* MSI TRX40 
Creator */
{ PCI_DEVICE_SUB(0x1022, 0x1487, 0x1462, 0xcb60) }, /* MSI TRX40 */
@@ -2101,8 +2101,8 @@ static int azx_probe(struct pci_dev *pci,
bool schedule_probe;
int err;
 
-   if (pci_match_id(driver_blacklist, pci)) {
-   dev_info(>dev, "Skipping the blacklisted device\n");
+   if (pci_match_id(driver_blocklist, pci)) {
+   dev_info(>dev, "Skipping the blocklisted device\n");
return -ENODEV;
}
 
@@ -2192,7 +2192,7 @@ static int azx_probe(struct pci_dev *pci,
  * So we keep a list of devices where we disable powersaving as its known
  * to causes problems on these devices.
  */
-static const struct snd_pci_quirk power_save_blacklist[] = {
+static const struct snd_pci_quirk power_save_blocklist[] = {
/* https://bugzilla.redhat

(my) kgdb patch brakes compile.

2001-02-22 Thread Paul Schulz

Greetings,

I have been sucessfully able to take Amit S. Kale ([EMAIL PROTECTED])
kgdb patch for 2.4.0-test9, and create a patch for 2.4.0-test12.

I am trying to create a patch for 2.4.1.. but gcc barfs with the
following:

-
make[3]: Entering directory `/usr/src/linux-2.4.1-kgdb/kernel'
gcc -D__KERNEL__ -I/usr/src/linux-2.4.1-kgdb/include -Wall -Wstrict-prototypes -g 
-pipe -mpreferred-stack-boundary=2 -march=i686-fno-omit-frame-pointer -c -o 
sched.o sched.c
sched.c: In function `schedule':
sched.c:648: Invalid `asm' statement:
sched.c:648: fixed or forbidden register 6 (bp) was spilled for class GENERAL_REGS.
make[3]: *** [sched.o] Error 1
make[3]: Leaving directory `/usr/src/linux-2.4.1-kgdb/kernel'
make[2]: *** [first_rule] Error 2
make[2]: Leaving directory `/usr/src/linux-2.4.1-kgdb/kernel'
make[1]: *** [_dir_kernel] Error 2
make[1]: Leaving directory `/usr/src/linux-2.4.1-kgdb'
make: *** [stamp-build] Error 2
-
This can be traced to include/asm_i386/system.h.. (switch_to)
-
#define prepare_to_switch() do { } while(0)
#Define switch_to(prev,next,last) do {  \
asm volatile("pushl %%esi\n\t"  \
 "pushl %%edi\n\t"  \
 "pushl %%ebp\n\t"  \
 "movl %%esp,%0\n\t"/* save ESP */  \
 "movl %3,%%esp\n\t"/* restore ESP */   \
 "movl $1f,%1\n\t"  /* save EIP */  \
 "pushl %4\n\t" /* restore EIP */   \
 "jmp __switch_to\n"\
 "1:\t" \
 "popl %%ebp\n\t"   \
 "popl %%edi\n\t"   \
 "popl %%esi\n\t"   \
 :"=m" (prev->thread.esp),"=m" (prev->thread.eip),  \
  "=b" (last)   \
 :"m" (next->thread.esp),"m" (next->thread.eip),\
  "a" (prev), "d" (next),   \
  "b" (prev));  \
} while (0)
-
Can someone explain what is the problem here? I'm assuming that it's 
one of the compile options.

The kgdb patch puts the following in the top level makefile...
and put a switch for $(CONFIG_X86_REMOTE_DEBUG) in the config tool.

The kernel compiles fine without the patch, and with the patch, 
with the option turned off.
-
CFLAGS := $(CPPFLAGS) -Wall -Wstrict-prototypes
ifeq ($(CONFIG_X86_REMOTE_DEBUG),y)
CFLAGS += -g
else
CFLAGS += -fomit-frame-pointer -O2 -fno-strict-aliasing
endif


Thanks,
Paul Schulz




-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/



(my) kgdb patch brakes compile.

2001-02-22 Thread Paul Schulz

Greetings,

I have been sucessfully able to take Amit S. Kale ([EMAIL PROTECTED])
kgdb patch for 2.4.0-test9, and create a patch for 2.4.0-test12.

I am trying to create a patch for 2.4.1.. but gcc barfs with the
following:

-
make[3]: Entering directory `/usr/src/linux-2.4.1-kgdb/kernel'
gcc -D__KERNEL__ -I/usr/src/linux-2.4.1-kgdb/include -Wall -Wstrict-prototypes -g 
-pipe -mpreferred-stack-boundary=2 -march=i686-fno-omit-frame-pointer -c -o 
sched.o sched.c
sched.c: In function `schedule':
sched.c:648: Invalid `asm' statement:
sched.c:648: fixed or forbidden register 6 (bp) was spilled for class GENERAL_REGS.
make[3]: *** [sched.o] Error 1
make[3]: Leaving directory `/usr/src/linux-2.4.1-kgdb/kernel'
make[2]: *** [first_rule] Error 2
make[2]: Leaving directory `/usr/src/linux-2.4.1-kgdb/kernel'
make[1]: *** [_dir_kernel] Error 2
make[1]: Leaving directory `/usr/src/linux-2.4.1-kgdb'
make: *** [stamp-build] Error 2
-
This can be traced to include/asm_i386/system.h.. (switch_to)
-
#define prepare_to_switch() do { } while(0)
#Define switch_to(prev,next,last) do {  \
asm volatile("pushl %%esi\n\t"  \
 "pushl %%edi\n\t"  \
 "pushl %%ebp\n\t"  \
 "movl %%esp,%0\n\t"/* save ESP */  \
 "movl %3,%%esp\n\t"/* restore ESP */   \
 "movl $1f,%1\n\t"  /* save EIP */  \
 "pushl %4\n\t" /* restore EIP */   \
 "jmp __switch_to\n"\
 "1:\t" \
 "popl %%ebp\n\t"   \
 "popl %%edi\n\t"   \
 "popl %%esi\n\t"   \
 :"=m" (prev-thread.esp),"=m" (prev-thread.eip),  \
  "=b" (last)   \
 :"m" (next-thread.esp),"m" (next-thread.eip),\
  "a" (prev), "d" (next),   \
  "b" (prev));  \
} while (0)
-
Can someone explain what is the problem here? I'm assuming that it's 
one of the compile options.

The kgdb patch puts the following in the top level makefile...
and put a switch for $(CONFIG_X86_REMOTE_DEBUG) in the config tool.

The kernel compiles fine without the patch, and with the patch, 
with the option turned off.
-
CFLAGS := $(CPPFLAGS) -Wall -Wstrict-prototypes
ifeq ($(CONFIG_X86_REMOTE_DEBUG),y)
CFLAGS += -g
else
CFLAGS += -fomit-frame-pointer -O2 -fno-strict-aliasing
endif


Thanks,
Paul Schulz




-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/



[Announcement] kgdb - unofficial (untested) patch available for 2.4.0

2001-01-08 Thread Paul Schulz

For those who are interested..

I have taken the kgdb patch for 2.4.0-test9 and ported it to 2.4.0.
This is a minimal patch, and doesn't include any of the documentation
or supporting programmes. It can be found at:

http://www.foursticks.com.au/~pschulz/kgdb
http://www.foursticks.com.au/~pschulz/kgdb/linux-2.4.0-kgdb.patch

There is also a patch for 2.4.0-test12

http://www.foursticks.com.au/~pschulz/kgdb/linux-2.4.0-test12-kgdb.patch

For more information see...

http://kgdb.sourceforge.net

kgdb is a patch to the linux kernel. It allows use of gdb for source level
debugging of a linux kernel. One can place breakpoints, step through code
and observe variables in the kernel similar to debugging a program.

For using kgdb you need two machines. One of these machines is the development
machine and the other is tests machine. The kernel to be debugged runs
on the tests machine. gdb runs on the development machine. The machines
are connected through a serial line. The serial line is used by gdb to
communicate to the kernel being debugged.



-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
Please read the FAQ at http://www.tux.org/lkml/



[Announcement] kgdb - unofficial (untested) patch available for 2.4.0

2001-01-08 Thread Paul Schulz

For those who are interested..

I have taken the kgdb patch for 2.4.0-test9 and ported it to 2.4.0.
This is a minimal patch, and doesn't include any of the documentation
or supporting programmes. It can be found at:

http://www.foursticks.com.au/~pschulz/kgdb
http://www.foursticks.com.au/~pschulz/kgdb/linux-2.4.0-kgdb.patch

There is also a patch for 2.4.0-test12

http://www.foursticks.com.au/~pschulz/kgdb/linux-2.4.0-test12-kgdb.patch

For more information see...

http://kgdb.sourceforge.net

kgdb is a patch to the linux kernel. It allows use of gdb for source level
debugging of a linux kernel. One can place breakpoints, step through code
and observe variables in the kernel similar to debugging a program.

For using kgdb you need two machines. One of these machines is the development
machine and the other is tests machine. The kernel to be debugged runs
on the tests machine. gdb runs on the development machine. The machines
are connected through a serial line. The serial line is used by gdb to
communicate to the kernel being debugged.



-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
Please read the FAQ at http://www.tux.org/lkml/



Re: how to compile redhat6.0 kernel

2000-12-02 Thread Paul Schulz

Mourad,

   i wanna recompile the kernel to reset some variables "ip multicasting",
   and i have a root access.

   so can you please tell me in steps (detailed) , how to recompile an
   installed kernel of redhat6.0.

Download the kernel source (or have a look in /usr/src/linux)
Read the 'README' in the home directory... 

   thanx
   mourad,   

   -
   To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
   the body of a message to [EMAIL PROTECTED]
   Please read the FAQ at http://www.tux.org/lkml/


-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
Please read the FAQ at http://www.tux.org/lkml/



Re: how to compile redhat6.0 kernel

2000-12-02 Thread Paul Schulz

Mourad,

   i wanna recompile the kernel to reset some variables "ip multicasting",
   and i have a root access.

   so can you please tell me in steps (detailed) , how to recompile an
   installed kernel of redhat6.0.

Download the kernel source (or have a look in /usr/src/linux)
Read the 'README' in the home directory... 

   thanx
   mourad,   

   -
   To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
   the body of a message to [EMAIL PROTECTED]
   Please read the FAQ at http://www.tux.org/lkml/


-
@@ -2074,11 +2074,11 @@ static void pcm_mmap_prepare(struct snd_pcm_substream 
 }
 
-/* Blacklist for skipping the whole probe:
+/* Blocklist for skipping the whole probe:
  * some HD-audio PCI entries are exposed without any codecs, and such devices
  * should be ignored from the beginning.
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
Please read the FAQ at http://www.tux.org/lkml/



[Patch] QoS as modules in 2.4.0-test10 not compiling.

2000-11-09 Thread Paul Schulz

Greetings,

I've been trying to compile the kernel with the QoS code as modules.

The net/Makefile didn't have 'sched' listed as a module subdirectory,
so it wasntt getting walked in a make_modules... any way, the
following patch fixes the problem.

Paul Schulz ([EMAIL PROTECTED])
Foursticks Systems

--
I (was) using 2.2.17 - which had problems you mentioned (different module).
2.4.0-test9 has the same problem.
--

Paul Schulz ([EMAIL PROTECTED])
Foursticks Systems


"J. S. Connell" <[EMAIL PROTECTED]> writes:

> Any time I disconnect and then reconnect the ethernet cable from my Netgear
> FA310TX cards, the card appears to not notice and doesn't reestablish the
> link.  Under 2.2.17pre4, the link light comes on, but until I do ifconfig
> ethX down; ifconfig ethX up, the kernel ignores any traffic on that
> interface (tcpdump on both an affected machine and a nonaffected machine
> show the kernel ignoring all incoming traffic, and not sending any traffic
> out.)  Under 2.4.0-test9-pre7, however, when I reconnect the ethernet
> cable, the link light does _not_ come on, and nothing short of a reboot
> will bring it back up.
> 
> I'm currently stuck at 2.2.17pre4 because I need André Hedrick's IDE patch,
> which won't apply (except manually) to later 2.2 kernels, and my attempts
> to apply the patch manually have ended in kernels that fail during boot.
> 
> In this system, eth0 is connected to a 10/100 Asanté FriendlyNet 8-port
> switch, and eth1 is connected to an RCA model DCM205 "digital|BROADBAND"
> cablemodem.
> 

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
Please read the FAQ at http://www.tux.org/lkml/



Patch for linux Configure.help (netfilter module descriptions)

2000-10-12 Thread Paul Schulz


Here is a patch against 2.4.0-test9, 
which adds information about the modules produced by netfilter.
Please let me know if it is suitable.

Paul Schulz

** This message was bounced when I tried to send it to: 
** Axil Boldt ([EMAIL PROTECTED])
** (Email address at the top of the file.. has this changed?)

-

diff -rU 3 kernel-source-2.4.0-test9/Documentation/Configure.help 
kernel-source-2.4.0-test9ps1/Documentation/Configure.help
--- kernel-source-2.4.0-test9/Documentation/Configure.help  Sat Sep 23 09:41:37 
2000
+++ kernel-source-2.4.0-test9ps1/Documentation/Configure.help   Wed Oct 11 23:30:13 
+2000
@@ -1821,8 +1821,11 @@
   enhance packet filtering (see `Connection state match support'
   below).
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ip_conntrack.o.  
+
+If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 FTP protocol support
 CONFIG_IP_NF_FTP
@@ -1830,16 +1833,18 @@
   required for tracking them, and doing masquerading and other forms
   of Network Address Translation on them.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `Y'.
+  This driver is also available as a module.  The module will be
+  called ip_conntrack_ftp.o.  If you want to compile it as a module,
+  say M here and read Documentation/modules.txt.  If unsure, say `Y'.
 
 IP: user space queueing via NETLINK (EXPERIMENTAL)
 CONFIG_IP_NF_QUEUE
   Netfilter has the ability to queue packets to user space: the
   netlink device can be used to access them using this driver.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ip_queue.o.  If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 IP: ip tables support (required for filtering/masq/NAT)
 CONFIG_IP_NF_IPTABLES
@@ -1848,8 +1853,9 @@
   etc) subsystems now use this: say `Y' or `M' here if you want to use
   either of those.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ip_tables.o.  If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 limit match support
 CONFIG_IP_NF_MATCH_LIMIT
@@ -1857,16 +1863,18 @@
   matched: mainly useful in combination with the LOG target ("LOG
   target support", below) and to avoid some Denial of Service attacks.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_limit.o. If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 MAC address match support
 CONFIG_IP_NF_MATCH_MAC
   mac matching allows you to match packets based on the source
   ethernet address of the packet.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_mac.o. If you want to compile it as a module, say M here
+  and read Documentation/modules.txt.  If unsure, say `N'.
 
 netfilter mark match support
 CONFIG_IP_NF_MATCH_MARK
@@ -1874,8 +1882,9 @@
   `nfmark' value in the packet.  This can be set by the MARK target
   (see below).
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_mark.o.  If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 Multiple port match support
 CONFIG_IP_NF_MATCH_MULTIPORT
@@ -1883,16 +1892,18 @@
   a series of source or destination ports: normally a rule can only
   match a single range of ports.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_multiport.o.  If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 TOS match support
 CONFIG_IP_NF_MATCH_TOS
   TOS matching allows you to match packets based on the Type Of
   Service fields of the IP packet.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_tos.o.  If you want 

Patch for linux Configure.help (netfilter module descriptions)

2000-10-12 Thread Paul Schulz


Here is a patch against 2.4.0-test9, 
which adds information about the modules produced by netfilter.
Please let me know if it is suitable.

Paul Schulz

** This message was bounced when I tried to send it to: 
** Axil Boldt ([EMAIL PROTECTED])
** (Email address at the top of the file.. has this changed?)

-

diff -rU 3 kernel-source-2.4.0-test9/Documentation/Configure.help 
kernel-source-2.4.0-test9ps1/Documentation/Configure.help
--- kernel-source-2.4.0-test9/Documentation/Configure.help  Sat Sep 23 09:41:37 
2000
+++ kernel-source-2.4.0-test9ps1/Documentation/Configure.help   Wed Oct 11 23:30:13 
+2000
@@ -1821,8 +1821,11 @@
   enhance packet filtering (see `Connection state match support'
   below).
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ip_conntrack.o.  
+
+If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 FTP protocol support
 CONFIG_IP_NF_FTP
@@ -1830,16 +1833,18 @@
   required for tracking them, and doing masquerading and other forms
   of Network Address Translation on them.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `Y'.
+  This driver is also available as a module.  The module will be
+  called ip_conntrack_ftp.o.  If you want to compile it as a module,
+  say M here and read Documentation/modules.txt.  If unsure, say `Y'.
 
 IP: user space queueing via NETLINK (EXPERIMENTAL)
 CONFIG_IP_NF_QUEUE
   Netfilter has the ability to queue packets to user space: the
   netlink device can be used to access them using this driver.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ip_queue.o.  If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 IP: ip tables support (required for filtering/masq/NAT)
 CONFIG_IP_NF_IPTABLES
@@ -1848,8 +1853,9 @@
   etc) subsystems now use this: say `Y' or `M' here if you want to use
   either of those.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ip_tables.o.  If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 limit match support
 CONFIG_IP_NF_MATCH_LIMIT
@@ -1857,16 +1863,18 @@
   matched: mainly useful in combination with the LOG target ("LOG
   target support", below) and to avoid some Denial of Service attacks.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_limit.o. If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 MAC address match support
 CONFIG_IP_NF_MATCH_MAC
   mac matching allows you to match packets based on the source
   ethernet address of the packet.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_mac.o. If you want to compile it as a module, say M here
+  and read Documentation/modules.txt.  If unsure, say `N'.
 
 netfilter mark match support
 CONFIG_IP_NF_MATCH_MARK
@@ -1874,8 +1882,9 @@
   `nfmark' value in the packet.  This can be set by the MARK target
   (see below).
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_mark.o.  If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 Multiple port match support
 CONFIG_IP_NF_MATCH_MULTIPORT
@@ -1883,16 +1892,18 @@
   a series of source or destination ports: normally a rule can only
   match a single range of ports.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_multiport.o.  If you want to compile it as a module, say M
+  here and read Documentation/modules.txt.  If unsure, say `N'.
 
 TOS match support
 CONFIG_IP_NF_MATCH_TOS
   TOS matching allows you to match packets based on the Type Of
   Service fields of the IP packet.
 
-  If you want to compile it as a module, say M here and read
-  Documentation/modules.txt.  If unsure, say `N'.
+  This driver is also available as a module.  The module will be
+  called ipt_tos.o.  If you want